package App::Beam::Backend;

use strict;
use Carp;

require Exporter;
our @ISA = qw(Exporter);
use App::Beam::Command qw(:channels);

sub new {
    my $class = shift;
    my $beam = shift or croak "required argument missing";
    return bless { beam => $beam }, $class;
}

sub logger {
    my $self = shift;
    $self->{beam}->logger(@_);
}

sub error {
    my $self = shift;
    $self->{beam}->error(@_);
}

sub debug {
    my $self = shift;
    $self->{beam}->debug(@_);
}

sub abend {
    my $self = shift;
    $self->{beam}->abend(@_);
}

sub dry_run {
    my ($self) = @_;
    return $self->{beam}{dry_run};
}

sub get {
    my $self = shift;
    return $self->{beam}->get(@_);
}

sub isset {
    my $self = shift;
    return $self->{beam}->isset(@_);
}

sub status {
    my $self = shift;
    return $self->{beam}->status(@_);
}

sub logcommand {
    my ($self, $cmd) = @_;
    my $ret = $cmd->status;
    return unless defined $ret;
    my $comname = $cmd->command_name;
    if ($ret) {
	if ($ret =~ /^open3:/) {
	    $self->logger('err', "failed to run $comname: $ret");
	} elsif ($ret == -1) {
	    $self->logger('err', "failed to run $comname");
	} elsif ($ret & 127) {
	    $self->logger('err',
			  "$comname exited on signal " . ($? & 127));
	} elsif (my $e = ($ret >> 8)) {
	    $self->logger('err',
			  "$comname exited with status $e");
	} else {
	    use Data::Dumper;
	    print Dumper([$ret]);
	}
	$self->logger('err', "command line was: ".$cmd->command_line);
    }

    my $fd = $cmd->channel(CHAN_STDERR);
    if (defined($fd)) {
	while (<$fd>) {
	    chomp;
	    $self->logger('err', "[$comname]: $_");
	}
    }
}

sub backup {
    my ($self, $item) = @_;
    $self->error("backup method not implemented",
		 locus => $self->get({variable => [ 'item', $item ],
				      return => '-locus'}));
}

1;
